@@ -84,12 +84,18 @@ class AutocompleteWidget(forms.HiddenInput):
 
     def value_elem(self, value):
         style = 'display:none'
-        label = ''
+        label = hasattr(self.model, "get_absolute_url") and format_html('<a></a>') or ''
         clear_elem = format_html('<span class="yaaac_clear_value">x</span>')
         if value:
             obj = self.model._default_manager.get(pk=value)
             label = Truncator(obj).words(14, truncate=" ...")
             style = ''
+            try:
+                url = obj.get_absolute_url()
+            except AttributeError:
+                pass
+            else:
+                label = format_html(u'<a{0}>{1}</a>', flatatt({"href": url}), label)
         label_elem = format_html(u'<span{0}>{1}</span>', flatatt({"class": "yaaac_value"}), label)
         return format_html(u'<span{0}>{1}{2}</span>',
                            flatatt({"class": "yaaac_value_container", "style": style}),
